==> aria2c-0.14.0b+20080611.tar.bz2: aria2c-0.14.0b+20080611/src/HttpSkipResponseCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_HTTP_SKIP_RESPONSE_COMMAND_H_
#define _D_HTTP_SKIP_RESPONSE_COMMAND_H_

#include "AbstractCommand.h"

namespace aria2 {

class HttpConnection;
class HttpResponse;
class TransferEncoding;

class HttpSkipResponseCommand : public AbstractCommand {
private:
  SharedHandle<HttpConnection> _httpConnection;

  SharedHandle<HttpResponse> _httpResponse;

  SharedHandle<TransferEncoding> _transferDecoder;

  uint64_t _totalLength;

  uint64_t _receivedBytes;

  bool processResponse();
protected:
  virtual bool executeInternal();
public:
  HttpSkipResponseCommand(int cuid,
			  const SharedHandle<Request>& req,
			  RequestGroup* requestGroup,
			  const SharedHandle<HttpConnection>& httpConnection,
			  const SharedHandle<HttpResponse>& httpResponse,
			  DownloadEngine* e,
			  const SharedHandle<SocketCore>& s);

  virtual ~HttpSkipResponseCommand();

  void setTransferDecoder(const SharedHandle<TransferEncoding>& transferDecoder);
};

} // namespace aria2

#endif // _D_HTTP_SKIP_RESPONSE_COMMAND_H_

==> aria2c-0.16.2.tar.bz2: aria2c-0.16.2/src/HttpSkipResponseCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_HTTP_SKIP_RESPONSE_COMMAND_H_
#define _D_HTTP_SKIP_RESPONSE_COMMAND_H_

#include "AbstractCommand.h"

namespace aria2 {

class HttpConnection;
class HttpResponse;
class Decoder;

class HttpSkipResponseCommand : public AbstractCommand {
private:
  SharedHandle<HttpConnection> _httpConnection;

  SharedHandle<HttpResponse> _httpResponse;

  SharedHandle<Decoder> _transferEncodingDecoder;

  uint64_t _totalLength;

  uint64_t _receivedBytes;

  bool processResponse();
protected:
  virtual bool executeInternal();
public:
  HttpSkipResponseCommand(int cuid,
			  const SharedHandle<Request>& req,
			  RequestGroup* requestGroup,
			  const SharedHandle<HttpConnection>& httpConnection,
			  const SharedHandle<HttpResponse>& httpResponse,
			  DownloadEngine* e,
			  const SharedHandle<SocketCore>& s);

  virtual ~HttpSkipResponseCommand();

  void setTransferEncodingDecoder(const SharedHandle<Decoder>& decoder);
};

} // namespace aria2

#endif // _D_HTTP_SKIP_RESPONSE_COMMAND_H_
